******************
What is excentury?
******************

Excentury is a collection of libraries written in several languages
to enable to the easy integration of C++ to scripting languages. The
current version of excentury only allows us to integrate C++ to
Python and MATLAB.
